package com.xinyilu.system.mapper.checkReportFailInfo;

import com.xinyilu.system.domain.checkReportFailInfo.CheckReportFailInfo;
import com.xinyilu.system.domain.dto.CheckReportFailInfoDTO;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 个人报告和幼儿园报告审核失败信息记录Mapper接口
 *
 * @author xinyilu
 * @date 2023-07-31
 */
public interface CheckReportFailInfoMapper {
    /**
     * 查询个人报告和幼儿园报告审核失败信息记录
     *
     * @param id 个人报告和幼儿园报告审核失败信息记录主键
     * @return 个人报告和幼儿园报告审核失败信息记录
     */
    public CheckReportFailInfo selectCheckReportFailInfoById(Long id);

    /**
     * 查询个人报告和幼儿园报告审核失败信息记录列表
     *
     * @param checkReportFailInfo 个人报告和幼儿园报告审核失败信息记录
     * @return 个人报告和幼儿园报告审核失败信息记录集合
     */
    public List<CheckReportFailInfoDTO> selectCheckReportFailInfoList(CheckReportFailInfo checkReportFailInfo);

    /**
     * 新增个人报告和幼儿园报告审核失败信息记录
     *
     * @param checkReportFailInfo 个人报告和幼儿园报告审核失败信息记录
     * @return 结果
     */
    public int insertCheckReportFailInfo(@Param("checkReportFailInfo") List<CheckReportFailInfoDTO> checkReportFailInfo);

    /**
     * 批量修改个人报告和幼儿园报告审核状态
     *
     * @param ids 需要修改的id
     * @return 结果
     */
    public int updateCheckReportFailInfoStatus(Long[] ids);

    /**
     * 修改个人报告和幼儿园报告审核失败信息记录
     *
     * @param checkReportFailInfo 个人报告和幼儿园报告审核失败信息记录
     * @return 结果
     */
    public int updateCheckReportFailInfo(CheckReportFailInfo checkReportFailInfo);

    /**
     * 删除个人报告和幼儿园报告审核失败信息记录
     *
     * @param id 个人报告和幼儿园报告审核失败信息记录主键
     * @return 结果
     */
    public int deleteCheckReportFailInfoById(Long id);

    /**
     * 批量删除个人报告和幼儿园报告审核失败信息记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCheckReportFailInfoByIds(Long[] ids);
}
